// (C) 2019-2025 GoodData Corporation
import React, { useCallback, useMemo, useState } from "react";
import { useIntl } from "react-intl";
import { AutofocusOnMount, InvertableSelectVirtualised, useMediaQuery } from "@gooddata/sdk-ui-kit";
import { useAttributeFilterComponentsContext } from "../../Context/AttributeFilterComponentsContext.js";
import { getElementTitle, getElementKey } from "../../utils.js";
import { usePrevious } from "@gooddata/sdk-ui";
import { useAttributeFilterContext } from "../../Context/AttributeFilterContext.js";
import { MAX_SELECTION_SIZE } from "../../hooks/constants.js";
const ITEM_HEIGHT = 28;
const MOBILE_LIST_ITEM_HEIGHT = 40;
const VISIBLE_ITEMS_COUNT = 10;
const MIN_LOADING_HEIGHT = 20;
const LOADING_PADDING = 32;
/**
 * This component allows users to search Attribute Filter elements.
 * It manipulates selection.
 * It displays statues like loading, filtering etc.
 * It allows paging.
 * It displays selection status like number of elements and selected elements labels.
 * It displays messages when elements are filtered out by parent filters or the result of search is empty.
 *
 * @internal
 */
export const AttributeFilterVirtualisedElementsSelect = (props) => {
    const { items, totalItemsCount, totalItemsCountWithCurrentSettings, isInverted, selectedItems, onSelect, searchString, onSearch, isLoading, isLoadingNextPage, nextPageSize, onLoadNextPage, error, attributeTitle, isFilteredByParentFilters, parentFilterTitles, enableShowingFilteredElements, onShowFilteredElements, irrelevantSelection, onClearIrrelevantSelection, onApplyButtonClick, isApplyDisabled, isFilteredByDependentDateFilters, withoutApply, } = props;
    const intl = useIntl();
    const isMobile = useMediaQuery("mobileDevice");
    const { fullscreenOnMobile, selectionMode, attribute } = useAttributeFilterContext();
    const { ElementsSelectLoadingComponent, ElementsSelectItemComponent, ElementsSelectErrorComponent, EmptyResultComponent, ElementsSearchBarComponent, ElementsSelectActionsComponent, StatusBarComponent, } = useAttributeFilterComponentsContext();
    const [refocusKey, setRefocusKey] = useState(undefined);
    const itemHeight = fullscreenOnMobile && isMobile ? MOBILE_LIST_ITEM_HEIGHT : ITEM_HEIGHT;
    const isAdaptiveHeight = isMobile && fullscreenOnMobile;
    const previousItemsCount = usePrevious(totalItemsCountWithCurrentSettings);
    const loadingHeight = useMemo(() => {
        return (Math.max((Math.min(previousItemsCount, VISIBLE_ITEMS_COUNT) || 1) * itemHeight, MIN_LOADING_HEIGHT) + LOADING_PADDING);
    }, [previousItemsCount, itemHeight]);
    const primaryLabelTitle = useMemo(() => {
        if (!attribute) {
            return null;
        }
        const primaryLabel = attribute.displayForms.find((df) => !!df.isPrimary);
        return primaryLabel?.title;
    }, [attribute]);
    const handleShowFilteredElements = useCallback(() => {
        setRefocusKey("show");
        onShowFilteredElements();
    }, [onShowFilteredElements, setRefocusKey]);
    return (React.createElement(AutofocusOnMount, { refocusKey: refocusKey },
        React.createElement(InvertableSelectVirtualised, { className: "gd-attribute-filter-elements-select__next", adaptiveWidth: true, adaptiveHeight: isAdaptiveHeight, isSingleSelect: selectionMode === "single", items: items, totalItemsCount: totalItemsCountWithCurrentSettings, itemHeight: itemHeight, getItemKey: getElementKey, getItemTitle: (item) => getElementTitle(item, intl), isInverted: isInverted, selectedItems: selectedItems, selectedItemsLimit: MAX_SELECTION_SIZE, onSelect: onSelect, onApplyButtonClick: onApplyButtonClick, searchString: searchString, onSearch: onSearch, canSubmitOnKeyDown: !isApplyDisabled, isLoading: isLoading, error: error, isLoadingNextPage: isLoadingNextPage, nextPageItemPlaceholdersCount: nextPageSize, onLoadNextPage: onLoadNextPage, numberOfHiddenSelectedItems: irrelevantSelection.length, renderItem: (props) => (React.createElement(ElementsSelectItemComponent, { ...props, primaryLabelTitle: primaryLabelTitle, fullscreenOnMobile: fullscreenOnMobile })), renderError: () => {
                return React.createElement(ElementsSelectErrorComponent, { error: error });
            }, renderLoading: () => {
                return React.createElement(ElementsSelectLoadingComponent, { height: loadingHeight });
            }, renderNoData: ({ height }) => (React.createElement(EmptyResultComponent, { height: height, isFilteredByParentFilters: isFilteredByParentFilters, isFilteredByDependentDateFilters: isFilteredByDependentDateFilters, searchString: searchString, totalItemsCount: totalItemsCount, parentFilterTitles: parentFilterTitles, enableShowingFilteredElements: enableShowingFilteredElements })), renderSearchBar: ({ onSearch, searchString }) => (React.createElement(ElementsSearchBarComponent, { onSearch: onSearch, searchString: searchString, isSmall: !(isMobile && fullscreenOnMobile) })), renderStatusBar: ({ getItemTitle, isInverted, selectedItems, selectedItemsLimit }) => (React.createElement(StatusBarComponent, { getItemTitle: getItemTitle, isFilteredByParentFilters: isFilteredByParentFilters, isFilteredByDependentDateFilters: isFilteredByDependentDateFilters, isInverted: isInverted, parentFilterTitles: parentFilterTitles, selectedItems: selectedItems, totalElementsCountWithCurrentSettings: totalItemsCountWithCurrentSettings, selectedItemsLimit: selectedItemsLimit, attributeTitle: attributeTitle, enableShowingFilteredElements: enableShowingFilteredElements, onShowFilteredElements: handleShowFilteredElements, irrelevantSelection: irrelevantSelection, onClearIrrelevantSelection: onClearIrrelevantSelection, withoutApply: withoutApply })), renderActions: ({ checked, onChange, onToggle, isFiltered, totalItemsCount, isPartialSelection, isVisible, }) => (React.createElement(ElementsSelectActionsComponent, { isVisible: isVisible, checked: checked, onChange: onChange, onToggle: onToggle, isFiltered: isFiltered, totalItemsCount: totalItemsCount, isPartialSelection: isPartialSelection, isApplyDisabled: isApplyDisabled, onApplyButtonClick: onApplyButtonClick })) })));
};
//# sourceMappingURL=AttributeFilterVirtualisedElementsSelect.js.map